summaryrefslogtreecommitdiffstats
path: root/kio
diff options
context:
space:
mode:
Diffstat (limited to 'kio')
-rw-r--r--kio/kfile/kdiroperator.cpp4
-rw-r--r--kio/kfile/kfileiconview.cpp2
-rw-r--r--kio/kfile/knotifydialog.h2
-rw-r--r--kio/kfile/kopenwith.cpp18
-rw-r--r--kio/kfile/kopenwith.h4
-rw-r--r--kio/kfile/kopenwith_p.h6
-rw-r--r--kio/kfile/kpropertiesdialog.cpp26
-rw-r--r--kio/kfile/kpropertiesdialog.h10
-rw-r--r--kio/kfile/tests/kcustommenueditortest.cpp2
-rw-r--r--kio/kfile/tests/kdirselectdialogtest.cpp2
-rw-r--r--kio/kfile/tests/kfiletreeviewtest.cpp2
-rw-r--r--kio/kfile/tests/kfstest.cpp2
-rw-r--r--kio/kfile/tests/kicondialogtest.cpp2
-rw-r--r--kio/kfile/tests/knotifytest.cpp2
-rw-r--r--kio/kfile/tests/kopenwithtest.cpp2
-rw-r--r--kio/kfile/tests/kurlrequestertest.cpp2
-rw-r--r--kio/kio/jobclasses.h2
-rw-r--r--kio/kio/kmessageboxwrapper.h4
-rw-r--r--kio/kio/kmimetype.cpp2
-rw-r--r--kio/kio/krun.cpp2
-rw-r--r--kio/kio/observer.cpp2
-rw-r--r--kio/kio/slave.cpp6
-rw-r--r--kio/kio/slavebase.cpp2
-rw-r--r--kio/kio/tcpslavebase.cpp8
-rw-r--r--kio/kioexec/README2
-rw-r--r--kio/kioexec/main.cpp2
-rw-r--r--kio/misc/kfile/fileprops.cpp2
-rw-r--r--kio/misc/kmailservice.cpp2
-rw-r--r--kio/misc/kntlm/kntlm.cpp4
-rw-r--r--kio/misc/ksendbugmail/main.cpp2
-rw-r--r--kio/misc/ktelnetservice.cpp2
-rw-r--r--kio/misc/kwalletd/kwalletd.cpp4
-rw-r--r--kio/tests/getalltest.cpp2
-rw-r--r--kio/tests/jobtest.cpp4
-rw-r--r--kio/tests/kacltest.cpp4
-rw-r--r--kio/tests/kdcopcheck.cpp2
-rw-r--r--kio/tests/kdefaultprogresstest.cpp2
-rw-r--r--kio/tests/kdirlistertest.cpp2
-rw-r--r--kio/tests/kdirwatchtest.cpp4
-rw-r--r--kio/tests/kionetrctest.cpp2
-rw-r--r--kio/tests/kiopassdlgtest.cpp2
-rw-r--r--kio/tests/kioslavetest.cpp2
-rw-r--r--kio/tests/kmimefromext.cpp2
-rw-r--r--kio/tests/kpropsdlgtest.cpp2
-rw-r--r--kio/tests/kprotocolinfotest.cpp2
-rw-r--r--kio/tests/kruntest.cpp2
-rw-r--r--kio/tests/kscantest.cpp2
-rw-r--r--kio/tests/ksycocatest.cpp2
-rw-r--r--kio/tests/ksycocaupdatetest.cpp2
-rw-r--r--kio/tests/ktradertest.cpp2
-rw-r--r--kio/tests/kurifiltertest.cpp2
-rw-r--r--kio/tests/kurlcompletiontest.cpp4
-rw-r--r--kio/tests/metatest.cpp4
-rw-r--r--kio/tests/netaccesstest.cpp2
-rw-r--r--kio/tests/previewtest.cpp2
-rw-r--r--kio/tests/speed.cpp2
56 files changed, 97 insertions, 97 deletions
diff --git a/kio/kfile/kdiroperator.cpp b/kio/kfile/kdiroperator.cpp
index c5e339b1a..f9e2d237c 100644
--- a/kio/kfile/kdiroperator.cpp
+++ b/kio/kfile/kdiroperator.cpp
@@ -1383,11 +1383,11 @@ void KDirOperator::setupMenu(int whichActions)
if (whichActions & FileActions)
{
actionMenu->insert( mkdirAction );
- if (currUrl.isLocalFile() && !(KApplication::keyboardMouseState() & TQt::ShiftButton))
+ if (currUrl.isLocalFile() && !(TDEApplication::keyboardMouseState() & TQt::ShiftButton))
actionMenu->insert( myActionCollection->action( "trash" ) );
KConfig *globalconfig = KGlobal::config();
KConfigGroupSaver cs( globalconfig, TQString::fromLatin1("KDE") );
- if (!currUrl.isLocalFile() || (KApplication::keyboardMouseState() & TQt::ShiftButton) ||
+ if (!currUrl.isLocalFile() || (TDEApplication::keyboardMouseState() & TQt::ShiftButton) ||
globalconfig->readBoolEntry("ShowDeleteCommand", false))
actionMenu->insert( myActionCollection->action( "delete" ) );
actionMenu->insert( actionSeparator );
diff --git a/kio/kfile/kfileiconview.cpp b/kio/kfile/kfileiconview.cpp
index 86bd5eeb2..10b8285c1 100644
--- a/kio/kfile/kfileiconview.cpp
+++ b/kio/kfile/kfileiconview.cpp
@@ -362,7 +362,7 @@ void KFileIconView::slotActivate( TQIconViewItem *item )
void KFileIconView::selected( TQIconViewItem *item )
{
- if ( !item || (KApplication::keyboardMouseState() & (ShiftButton | ControlButton)) != 0 )
+ if ( !item || (TDEApplication::keyboardMouseState() & (ShiftButton | ControlButton)) != 0 )
return;
if ( KGlobalSettings::singleClick() ) {
diff --git a/kio/kfile/knotifydialog.h b/kio/kfile/knotifydialog.h
index 165df42f4..2adb2b15a 100644
--- a/kio/kfile/knotifydialog.h
+++ b/kio/kfile/knotifydialog.h
@@ -96,7 +96,7 @@ public:
* KNotifyDialog can handle events for multiple applications (i.e. eventsrc files).
* Successive calls with a different @p appName will add them.
* @param appName The application's name, i.e. the name passed to the
- * KApplication constructor or KAboutData.
+ * TDEApplication constructor or KAboutData.
* @see clearApplicationEvents()
*/
virtual void addApplicationEvents( const char *appName );
diff --git a/kio/kfile/kopenwith.cpp b/kio/kfile/kopenwith.cpp
index 8f498aa8d..c8623ced2 100644
--- a/kio/kfile/kopenwith.cpp
+++ b/kio/kfile/kopenwith.cpp
@@ -131,7 +131,7 @@ void KAppTreeListItem::activate()
void KAppTreeListItem::setOpen( bool o )
{
if( o && !parsed ) { // fill the children before opening
- ((KApplicationTree *) parent())->addDesktopGroup( path, this );
+ ((TDEApplicationTree *) parent())->addDesktopGroup( path, this );
parsed = true;
}
TQListViewItem::setOpen( o );
@@ -144,7 +144,7 @@ bool KAppTreeListItem::isDirectory()
// ----------------------------------------------------------------------
-KApplicationTree::KApplicationTree( TQWidget *parent )
+TDEApplicationTree::TDEApplicationTree( TQWidget *parent )
: KListView( parent ), currentitem(0)
{
addColumn( i18n("Known Applications") );
@@ -161,7 +161,7 @@ KApplicationTree::KApplicationTree( TQWidget *parent )
// ----------------------------------------------------------------------
-bool KApplicationTree::isDirSel()
+bool TDEApplicationTree::isDirSel()
{
if (!currentitem) return false; // if currentitem isn't set
return currentitem->isDirectory();
@@ -182,7 +182,7 @@ static TQPixmap appIcon(const TQString &iconName)
return normal;
}
-void KApplicationTree::addDesktopGroup( const TQString &relPath, KAppTreeListItem *item)
+void TDEApplicationTree::addDesktopGroup( const TQString &relPath, KAppTreeListItem *item)
{
KServiceGroup::Ptr root = KServiceGroup::group(relPath);
if (!root || !root->isValid()) return;
@@ -244,7 +244,7 @@ void KApplicationTree::addDesktopGroup( const TQString &relPath, KAppTreeListIte
// ----------------------------------------------------------------------
-void KApplicationTree::slotItemHighlighted(TQListViewItem* i)
+void TDEApplicationTree::slotItemHighlighted(TQListViewItem* i)
{
// i may be 0 (see documentation)
if(!i)
@@ -261,7 +261,7 @@ void KApplicationTree::slotItemHighlighted(TQListViewItem* i)
// ----------------------------------------------------------------------
-void KApplicationTree::slotSelectionChanged(TQListViewItem* i)
+void TDEApplicationTree::slotSelectionChanged(TQListViewItem* i)
{
// i may be 0 (see documentation)
if(!i)
@@ -277,7 +277,7 @@ void KApplicationTree::slotSelectionChanged(TQListViewItem* i)
// ----------------------------------------------------------------------
-void KApplicationTree::resizeEvent( TQResizeEvent * e)
+void TDEApplicationTree::resizeEvent( TQResizeEvent * e)
{
setColumnWidth(0, width()-TQApplication::style().pixelMetric(TQStyle::PM_ScrollBarExtent)
-2*TQApplication::style().pixelMetric(TQStyle::PM_DefaultFrameWidth));
@@ -285,7 +285,7 @@ void KApplicationTree::resizeEvent( TQResizeEvent * e)
}
// Prune empty directories from the tree
-void KApplicationTree::cleanupTree()
+void TDEApplicationTree::cleanupTree()
{
TQListViewItem *item=firstChild();
while(item!=0)
@@ -456,7 +456,7 @@ void KOpenWithDlg::init( const TQString& _text, const TQString& _value )
connect ( edit, TQT_SIGNAL(returnPressed()), TQT_SLOT(slotOK()) );
connect ( edit, TQT_SIGNAL(textChanged(const TQString&)), TQT_SLOT(slotTextChanged()) );
- m_pTree = new KApplicationTree( this );
+ m_pTree = new TDEApplicationTree( this );
topLayout->addWidget(m_pTree);
connect( m_pTree, TQT_SIGNAL( selected( const TQString&, const TQString& ) ),
diff --git a/kio/kfile/kopenwith.h b/kio/kfile/kopenwith.h
index 3dceb10bc..a6c570172 100644
--- a/kio/kfile/kopenwith.h
+++ b/kio/kfile/kopenwith.h
@@ -26,7 +26,7 @@
#include <krun.h>
#include <kservice.h>
-class KApplicationTree;
+class TDEApplicationTree;
class KURLRequester;
class TQWidget;
@@ -161,7 +161,7 @@ protected:
KURLRequester * edit;
TQString m_command;
- KApplicationTree* m_pTree;
+ TDEApplicationTree* m_pTree;
TQLabel *label;
TQString qName, qServiceType;
diff --git a/kio/kfile/kopenwith_p.h b/kio/kfile/kopenwith_p.h
index f395d94bd..8231da27d 100644
--- a/kio/kfile/kopenwith_p.h
+++ b/kio/kfile/kopenwith_p.h
@@ -61,7 +61,7 @@ protected:
virtual void activate();
virtual void setOpen( bool o );
- friend class KApplicationTree;
+ friend class TDEApplicationTree;
};
/* ------------------------------------------------------------------------- */
@@ -69,11 +69,11 @@ protected:
/**
* @internal
*/
-class KApplicationTree : public KListView
+class TDEApplicationTree : public KListView
{
Q_OBJECT
public:
- KApplicationTree( TQWidget *parent );
+ TDEApplicationTree( TQWidget *parent );
/**
* Add a group of .desktop/.kdelnk entries
diff --git a/kio/kfile/kpropertiesdialog.h b/kio/kfile/kpropertiesdialog.h
index 91439f8cc..d6a8223dd 100644
--- a/kio/kfile/kpropertiesdialog.h
+++ b/kio/kfile/kpropertiesdialog.h
@@ -878,15 +878,15 @@ private:
* @deprecated replaced with KDesktopPropsPlugin
*/
/// Remove in KDE4
-class KIO_EXPORT_DEPRECATED KApplicationPropsPlugin : public KPropsDlgPlugin
+class KIO_EXPORT_DEPRECATED TDEApplicationPropsPlugin : public KPropsDlgPlugin
{
Q_OBJECT
public:
/**
* Constructor
*/
- KApplicationPropsPlugin( KPropertiesDialog *_props );
- virtual ~KApplicationPropsPlugin();
+ TDEApplicationPropsPlugin( KPropertiesDialog *_props );
+ virtual ~TDEApplicationPropsPlugin();
virtual void applyChanges();
@@ -910,8 +910,8 @@ private:
TQPushButton *addExtensionButton;
TQPushButton *delExtensionButton;
- class KApplicationPropsPluginPrivate;
- KApplicationPropsPluginPrivate *d;
+ class TDEApplicationPropsPluginPrivate;
+ TDEApplicationPropsPluginPrivate *d;
};
#endif
diff --git a/kio/kfile/tests/kcustommenueditortest.cpp b/kio/kfile/tests/kcustommenueditortest.cpp
index 859e75452..9e00687ac 100644
--- a/kio/kfile/tests/kcustommenueditortest.cpp
+++ b/kio/kfile/tests/kcustommenueditortest.cpp
@@ -6,7 +6,7 @@
int main(int argc, char** argv)
{
KLocale::setMainCatalogue("tdelibs");
- KApplication app(argc, argv, "KCustomMenuEditorTest");
+ TDEApplication app(argc, argv, "KCustomMenuEditorTest");
KCustomMenuEditor editor(0);
KConfig *cfg = new KConfig("kdesktop_custom_menu2");
editor.load(cfg);
diff --git a/kio/kfile/tests/kdirselectdialogtest.cpp b/kio/kfile/tests/kdirselectdialogtest.cpp
index 47fcd02ca..3d15c47d0 100644
--- a/kio/kfile/tests/kdirselectdialogtest.cpp
+++ b/kio/kfile/tests/kdirselectdialogtest.cpp
@@ -5,7 +5,7 @@
int main( int argc, char **argv )
{
- KApplication app(argc, argv, "kdirselectdialogtest");
+ TDEApplication app(argc, argv, "kdirselectdialogtest");
KURL u = KDirSelectDialog::selectDirectory( (argc >= 1) ? argv[1] : TQString::null );
if ( u.isValid() )
diff --git a/kio/kfile/tests/kfiletreeviewtest.cpp b/kio/kfile/tests/kfiletreeviewtest.cpp
index 5c520dd5d..e131bda3a 100644
--- a/kio/kfile/tests/kfiletreeviewtest.cpp
+++ b/kio/kfile/tests/kfiletreeviewtest.cpp
@@ -134,7 +134,7 @@ void testFrame::slotSetChildCount( KFileTreeViewItem *item, int c )
int main(int argc, char **argv)
{
- KApplication a(argc, argv, "kfiletreeviewtest");
+ TDEApplication a(argc, argv, "kfiletreeviewtest");
TQString name1;
TQStringList names;
diff --git a/kio/kfile/tests/kfstest.cpp b/kio/kfile/tests/kfstest.cpp
index db3f46e28..f85995a61 100644
--- a/kio/kfile/tests/kfstest.cpp
+++ b/kio/kfile/tests/kfstest.cpp
@@ -44,7 +44,7 @@
int main(int argc, char **argv)
{
- KApplication a(argc, argv, "kfstest");
+ TDEApplication a(argc, argv, "kfstest");
TQString name1;
TQStringList names;
diff --git a/kio/kfile/tests/kicondialogtest.cpp b/kio/kfile/tests/kicondialogtest.cpp
index 23301b752..b2c56e159 100644
--- a/kio/kfile/tests/kicondialogtest.cpp
+++ b/kio/kfile/tests/kicondialogtest.cpp
@@ -3,7 +3,7 @@
int main( int argc, char **argv )
{
- KApplication app( argc, argv, "kicondialogtest" );
+ TDEApplication app( argc, argv, "kicondialogtest" );
// KIconDialog::getIcon();
diff --git a/kio/kfile/tests/knotifytest.cpp b/kio/kfile/tests/knotifytest.cpp
index f6e93fa99..0493b59b4 100644
--- a/kio/kfile/tests/knotifytest.cpp
+++ b/kio/kfile/tests/knotifytest.cpp
@@ -3,7 +3,7 @@
int main( int argc, char **argv )
{
- KApplication app( argc, argv, "knotifytest" );
+ TDEApplication app( argc, argv, "knotifytest" );
KNotifyDialog *dlg = new KNotifyDialog();
dlg->addApplicationEvents( "twin" );
return dlg->exec();
diff --git a/kio/kfile/tests/kopenwithtest.cpp b/kio/kfile/tests/kopenwithtest.cpp
index ea348a94c..f78b1830b 100644
--- a/kio/kfile/tests/kopenwithtest.cpp
+++ b/kio/kfile/tests/kopenwithtest.cpp
@@ -28,7 +28,7 @@
int main(int argc, char **argv)
{
- KApplication app(argc, argv, "kopenwithtest");
+ TDEApplication app(argc, argv, "kopenwithtest");
KURL::List list;
list += KURL("file:///tmp/testfile.txt");
diff --git a/kio/kfile/tests/kurlrequestertest.cpp b/kio/kfile/tests/kurlrequestertest.cpp
index 99af39814..0e4851cfb 100644
--- a/kio/kfile/tests/kurlrequestertest.cpp
+++ b/kio/kfile/tests/kurlrequestertest.cpp
@@ -5,7 +5,7 @@
int main( int argc, char **argv )
{
- KApplication app( argc, argv, "kurlrequestertest" );
+ TDEApplication app( argc, argv, "kurlrequestertest" );
KURL url = KURLRequesterDlg::getURL( "ftp://ftp.kde.org" );
tqDebug( "Selected url: %s", url.url().latin1());
diff --git a/kio/kio/jobclasses.h b/kio/kio/jobclasses.h
index d937e8700..9d6624dc0 100644
--- a/kio/kio/jobclasses.h
+++ b/kio/kio/jobclasses.h
@@ -230,7 +230,7 @@ namespace KIO {
/**
* Updates the last user action timestamp to the given time.
- * See KApplication::updateUserTimestamp() .
+ * See TDEApplication::updateUserTimestamp() .
* @since 3.5.6
*/
void updateUserTimestamp( unsigned long time );
diff --git a/kio/kio/kmessageboxwrapper.h b/kio/kio/kmessageboxwrapper.h
index 94a960135..356d98042 100644
--- a/kio/kio/kmessageboxwrapper.h
+++ b/kio/kio/kmessageboxwrapper.h
@@ -34,7 +34,7 @@ public:
const TQString &text,
const TQString &caption = TQString::null)
{
- if (KApplication::guiEnabled()) {
+ if (TDEApplication::guiEnabled()) {
kapp->enableStyles();
KMessageBox::error( parent, text, caption );
} else
@@ -45,7 +45,7 @@ public:
const TQString &text,
const TQString &caption = TQString::null)
{
- if (KApplication::guiEnabled()) {
+ if (TDEApplication::guiEnabled()) {
kapp->enableStyles();
KMessageBox::sorry( parent, text, caption );
} else
diff --git a/kio/kio/kmimetype.cpp b/kio/kio/kmimetype.cpp
index 461207d9a..09a45b5ea 100644
--- a/kio/kio/kmimetype.cpp
+++ b/kio/kio/kmimetype.cpp
@@ -900,7 +900,7 @@ pid_t KDEDesktopMimeType::runMimeType( const KURL& url , const KSimpleConfig & )
args << url.path();
int pid;
- if ( !KApplication::tdeinitExec("kfmclient", args, 0, &pid) )
+ if ( !TDEApplication::tdeinitExec("kfmclient", args, 0, &pid) )
return pid;
KProcess p;
diff --git a/kio/kio/krun.cpp b/kio/kio/krun.cpp
index 93cbe677a..cbc72242e 100644
--- a/kio/kio/krun.cpp
+++ b/kio/kio/krun.cpp
@@ -818,7 +818,7 @@ pid_t KRun::run( const KService& _service, const KURL::List& _urls, TQWidget* wi
}
}
- int i = KApplication::startServiceByDesktopPath(
+ int i = TDEApplication::startServiceByDesktopPath(
_service.desktopEntryPath(), urls.toStringList(), &error, 0L, &pid, myasn
);
diff --git a/kio/kio/observer.cpp b/kio/kio/observer.cpp
index 2a468b1e6..599703f9b 100644
--- a/kio/kio/observer.cpp
+++ b/kio/kio/observer.cpp
@@ -61,7 +61,7 @@ Observer::Observer() : DCOPObject("KIO::Observer")
{
kdDebug(KDEBUG_OBSERVER) << "Starting kio_uiserver" << endl;
TQString error;
- int ret = KApplication::startServiceByDesktopPath( "kio_uiserver.desktop",
+ int ret = TDEApplication::startServiceByDesktopPath( "kio_uiserver.desktop",
TQStringList(), &error );
if ( ret > 0 )
{
diff --git a/kio/kio/slave.cpp b/kio/kio/slave.cpp
index 3a501d681..29b8482fb 100644
--- a/kio/kio/slave.cpp
+++ b/kio/kio/slave.cpp
@@ -245,7 +245,7 @@ void Slave::hold(const KURL &url)
pid_t pid = m_pid;
stream << pid;
- TQCString launcher = KApplication::launcher();
+ TQCString launcher = TDEApplication::launcher();
client->call(launcher, launcher, "waitForSlave(pid_t)",
params, replyType, reply);
}
@@ -431,7 +431,7 @@ Slave* Slave::createSlave( const TQString &protocol, const KURL& url, int& error
TQDataStream stream(params, IO_WriteOnly);
stream << protocol << url.host() << socketfile.name();
- TQCString launcher = KApplication::launcher();
+ TQCString launcher = TDEApplication::launcher();
if (!client->call(launcher, launcher, "requestSlave(TQString,TQString,TQString)",
params, replyType, reply)) {
error_text = i18n("Cannot talk to klauncher");
@@ -491,7 +491,7 @@ Slave* Slave::holdSlave( const TQString &protocol, const KURL& url )
TQDataStream stream(params, IO_WriteOnly);
stream << url << socketfile.name();
- TQCString launcher = KApplication::launcher();
+ TQCString launcher = TDEApplication::launcher();
if (!client->call(launcher, launcher, "requestHoldSlave(KURL,TQString)",
params, replyType, reply)) {
delete slave;
diff --git a/kio/kio/slavebase.cpp b/kio/kio/slavebase.cpp
index d0734105c..d2e807077 100644
--- a/kio/kio/slavebase.cpp
+++ b/kio/kio/slavebase.cpp
@@ -246,7 +246,7 @@ DCOPClient *SlaveBase::dcopClient()
{
if (!d->dcopClient)
{
- d->dcopClient = KApplication::dcopClient();
+ d->dcopClient = TDEApplication::dcopClient();
if (!d->dcopClient->isAttached())
d->dcopClient->attach();
d->dcopClient->setDaemonMode( true );
diff --git a/kio/kio/tcpslavebase.cpp b/kio/kio/tcpslavebase.cpp
index 672cc0a5c..dc556ea23 100644
--- a/kio/kio/tcpslavebase.cpp
+++ b/kio/kio/tcpslavebase.cpp
@@ -631,7 +631,7 @@ KSSLCertificateHome::KSSLAuthAction aa;
d->dcc = new DCOPClient;
d->dcc->attach();
if (!d->dcc->isApplicationRegistered("kio_uiserver")) {
- KApplication::startServiceByDesktopPath("kio_uiserver.desktop",
+ TDEApplication::startServiceByDesktopPath("kio_uiserver.desktop",
TQStringList() );
}
}
@@ -895,7 +895,7 @@ int TCPSlaveBase::verifyCertificate()
d->dcc = new DCOPClient;
d->dcc->attach();
if (!d->dcc->isApplicationRegistered("kio_uiserver")) {
- KApplication::startServiceByDesktopPath("kio_uiserver.desktop",
+ TDEApplication::startServiceByDesktopPath("kio_uiserver.desktop",
TQStringList() );
}
@@ -1023,7 +1023,7 @@ int TCPSlaveBase::verifyCertificate()
d->dcc = new DCOPClient;
d->dcc->attach();
if (!d->dcc->isApplicationRegistered("kio_uiserver")) {
- KApplication::startServiceByDesktopPath("kio_uiserver.desktop",
+ TDEApplication::startServiceByDesktopPath("kio_uiserver.desktop",
TQStringList() );
}
}
@@ -1107,7 +1107,7 @@ int TCPSlaveBase::verifyCertificate()
d->dcc = new DCOPClient;
d->dcc->attach();
if (!d->dcc->isApplicationRegistered("kio_uiserver")) {
- KApplication::startServiceByDesktopPath("kio_uiserver.desktop",
+ TDEApplication::startServiceByDesktopPath("kio_uiserver.desktop",
TQStringList() );
}
}
diff --git a/kio/kioexec/README b/kio/kioexec/README
index 9f844bb97..daaa38bdb 100644
--- a/kio/kioexec/README
+++ b/kio/kioexec/README
@@ -14,7 +14,7 @@ so we have no way to know when the user finished editing the file...
Conclusion: if the application has network transparency built-in, it should
put "%u" in its desktop file - and kfmexec isn't used -. If it doesn't, either
-it's a KApplication and kfmexec does its job, or it's a KUniqueApplication
+it's a TDEApplication and kfmexec does its job, or it's a KUniqueApplication
and... kfmexec can't see modifications to the file. Be warned.
From Waldo: "The program doesn't return _at once_. It returns
diff --git a/kio/kioexec/main.cpp b/kio/kioexec/main.cpp
index 772c27f73..18014f08f 100644
--- a/kio/kioexec/main.cpp
+++ b/kio/kioexec/main.cpp
@@ -283,7 +283,7 @@ int main( int argc, char **argv )
TDECmdLineArgs::init( argc, argv, &aboutData );
TDECmdLineArgs::addCmdLineOptions( options );
- KApplication app;
+ TDEApplication app;
KIOExec exec;
diff --git a/kio/misc/kfile/fileprops.cpp b/kio/misc/kfile/fileprops.cpp
index ac9954563..cba281cc7 100644
--- a/kio/misc/kfile/fileprops.cpp
+++ b/kio/misc/kfile/fileprops.cpp
@@ -423,7 +423,7 @@ int main( int argc, char **argv )
TDECmdLineArgs *args = TDECmdLineArgs::parsedArgs();
bool useGUI = args->isSet( "dialog" );
- KApplication app( useGUI, useGUI );
+ TDEApplication app( useGUI, useGUI );
TQPtrList<FileProps> m_props;
m_props.setAutoDelete( true );
diff --git a/kio/misc/kmailservice.cpp b/kio/misc/kmailservice.cpp
index a9f59ca36..3b2eb8cf7 100644
--- a/kio/misc/kmailservice.cpp
+++ b/kio/misc/kmailservice.cpp
@@ -32,7 +32,7 @@ int main( int argc, char **argv )
TDECmdLineArgs::init( argc, argv, "kmailservice", I18N_NOOP("KMailService"), I18N_NOOP("Mail service"), "unknown" );
TDECmdLineArgs::addCmdLineOptions( options );
- KApplication a( false, false );
+ TDEApplication a( false, false );
TDECmdLineArgs *args = TDECmdLineArgs::parsedArgs();
diff --git a/kio/misc/kntlm/kntlm.cpp b/kio/misc/kntlm/kntlm.cpp
index 9af382483..dd9cd33ec 100644
--- a/kio/misc/kntlm/kntlm.cpp
+++ b/kio/misc/kntlm/kntlm.cpp
@@ -265,7 +265,7 @@ TQByteArray KNTLM::getLMv2Response( const TQString &target, const TQString &user
TQByteArray hash = ntlmv2Hash( target, user, password );
TQByteArray clientChallenge( 8 );
for ( uint i = 0; i<8; i++ ) {
- clientChallenge.data()[i] = KApplication::random() % 0xff;
+ clientChallenge.data()[i] = TDEApplication::random() % 0xff;
}
return lmv2Response( hash, clientChallenge, challenge );
}
@@ -304,7 +304,7 @@ TQByteArray KNTLM::createBlob( const TQByteArray &targetinfo )
now *= (TQ_UINT64)10000000;
bl->timestamp = KFromToLittleEndian( now );
for ( uint i = 0; i<8; i++ ) {
- bl->challenge[i] = KApplication::random() % 0xff;
+ bl->challenge[i] = TDEApplication::random() % 0xff;
}
memcpy( blob.data() + sizeof(Blob), targetinfo.data(), targetinfo.size() );
return blob;
diff --git a/kio/misc/ksendbugmail/main.cpp b/kio/misc/ksendbugmail/main.cpp
index 1f900426f..527d8545f 100644
--- a/kio/misc/ksendbugmail/main.cpp
+++ b/kio/misc/ksendbugmail/main.cpp
@@ -68,7 +68,7 @@ int main(int argc, char **argv) {
TDECmdLineArgs::addCmdLineOptions(options);
TDECmdLineArgs *args = TDECmdLineArgs::parsedArgs();
- KApplication a(false, false);
+ TDEApplication a(false, false);
TQCString recipient = args->getOption("recipient");
if (recipient.isEmpty())
diff --git a/kio/misc/ktelnetservice.cpp b/kio/misc/ktelnetservice.cpp
index d0f93aaf1..ea8708863 100644
--- a/kio/misc/ktelnetservice.cpp
+++ b/kio/misc/ktelnetservice.cpp
@@ -42,7 +42,7 @@ int main(int argc, char **argv)
I18N_NOOP("telnet protocol handler"), "unknown");
TDECmdLineArgs::addCmdLineOptions(options);
- KApplication app;
+ TDEApplication app;
TDECmdLineArgs *args = TDECmdLineArgs::parsedArgs();
diff --git a/kio/misc/kwalletd/kwalletd.cpp b/kio/misc/kwalletd/kwalletd.cpp
index eca13c463..a88f4e5b1 100644
--- a/kio/misc/kwalletd/kwalletd.cpp
+++ b/kio/misc/kwalletd/kwalletd.cpp
@@ -95,7 +95,7 @@ KWalletD::KWalletD(const TQCString &name)
connect(_timeouts, TQT_SIGNAL(timedOut(int)), this, TQT_SLOT(timedOut(int)));
reconfigure();
KGlobal::dirs()->addResourceType("kwallet", "share/apps/kwallet");
- connect(KApplication::dcopClient(),
+ connect(TDEApplication::dcopClient(),
TQT_SIGNAL(applicationRemoved(const TQCString&)),
this,
TQT_SLOT(slotAppUnregistered(const TQCString&)));
@@ -526,7 +526,7 @@ int KWalletD::internalOpen(const TQCString& appid, const TQString& wallet, bool
}
emitDCOPSignal("walletOpened(TQString)", data);
if (_wallets.count() == 1 && _launchManager) {
- KApplication::startServiceByDesktopName("kwalletmanager-kwalletd");
+ TDEApplication::startServiceByDesktopName("kwalletmanager-kwalletd");
}
} else {
if (!_handles[appid].contains(rc) && _openPrompt && !isAuthorizedApp(appid, wallet, w)) {
diff --git a/kio/tests/getalltest.cpp b/kio/tests/getalltest.cpp
index 58c8d5a3f..07d8723ed 100644
--- a/kio/tests/getalltest.cpp
+++ b/kio/tests/getalltest.cpp
@@ -7,7 +7,7 @@
int main(int argc, char *argv[])
{
- KApplication k(argc,argv,"getalltest",false/*noGUI*/); // KMessageBox needs KApp for makeStdCaption
+ TDEApplication k(argc,argv,"getalltest",false/*noGUI*/); // KMessageBox needs KApp for makeStdCaption
//for (int i = 0 ; i < 2 ; ++i ) { // test twice to see if they got deleted
kdDebug() << "All services" << endl;
diff --git a/kio/tests/jobtest.cpp b/kio/tests/jobtest.cpp
index 34fe93677..cd9a99bb8 100644
--- a/kio/tests/jobtest.cpp
+++ b/kio/tests/jobtest.cpp
@@ -64,9 +64,9 @@ static bool check(const TQString& txt, TQString a, TQString b)
int main(int argc, char *argv[])
{
- KApplication::disableAutoDcopRegistration();
+ TDEApplication::disableAutoDcopRegistration();
TDECmdLineArgs::init(argc,argv,"jobtest", 0, 0, 0, 0);
- KApplication app;
+ TDEApplication app;
JobTest test;
test.setup();
diff --git a/kio/tests/kacltest.cpp b/kio/tests/kacltest.cpp
index b4bfc9f07..45ace585f 100644
--- a/kio/tests/kacltest.cpp
+++ b/kio/tests/kacltest.cpp
@@ -67,9 +67,9 @@ static bool check(const TQString& txt, T a, T b)
int main(int argc, char *argv[])
{
- KApplication::disableAutoDcopRegistration();
+ TDEApplication::disableAutoDcopRegistration();
TDECmdLineArgs::init(argc,argv,"kacltest", 0, 0, 0, 0);
- KApplication app;
+ TDEApplication app;
KACLTest test;
test.setup();
diff --git a/kio/tests/kdcopcheck.cpp b/kio/tests/kdcopcheck.cpp
index 7d373824e..1626f2ebc 100644
--- a/kio/tests/kdcopcheck.cpp
+++ b/kio/tests/kdcopcheck.cpp
@@ -91,7 +91,7 @@ int TestService::exec()
int main(int argc, char *argv[])
{
putenv("IGNORE_SYCOCA_VERSION=true");
- KApplication k(argc,argv,"whatever",false/*noGUI*/); // KMessageBox needs KApp for makeStdCaption
+ TDEApplication k(argc,argv,"whatever",false/*noGUI*/); // KMessageBox needs KApp for makeStdCaption
k.dcopClient()->setNotifications(true);
diff --git a/kio/tests/kdefaultprogresstest.cpp b/kio/tests/kdefaultprogresstest.cpp
index a831041e1..e62408204 100644
--- a/kio/tests/kdefaultprogresstest.cpp
+++ b/kio/tests/kdefaultprogresstest.cpp
@@ -7,7 +7,7 @@ using namespace KIO;
int main(int argc, char **argv)
{
- KApplication app(argc, argv, "kdefaultprogresstest");
+ TDEApplication app(argc, argv, "kdefaultprogresstest");
DefaultProgress* dlg = new DefaultProgress();
KURL src("http://this.host.doesn't.exist/this/dir/neither/andthisfileneither");
diff --git a/kio/tests/kdirlistertest.cpp b/kio/tests/kdirlistertest.cpp
index 6137f5e71..01d0a36e9 100644
--- a/kio/tests/kdirlistertest.cpp
+++ b/kio/tests/kdirlistertest.cpp
@@ -151,7 +151,7 @@ void KDirListerTest::completed()
int main ( int argc, char *argv[] )
{
- KApplication app( argc, argv, "kdirlistertest" );
+ TDEApplication app( argc, argv, "kdirlistertest" );
KDirListerTest *test = new KDirListerTest( 0 );
test->show();
diff --git a/kio/tests/kdirwatchtest.cpp b/kio/tests/kdirwatchtest.cpp
index 20676ee49..c741b20f0 100644
--- a/kio/tests/kdirwatchtest.cpp
+++ b/kio/tests/kdirwatchtest.cpp
@@ -28,9 +28,9 @@ int main (int argc, char **argv)
TDECmdLineArgs::init(argc, argv, "KDirWatchTest",
"Test for KDirWatch", "1.0");
TDECmdLineArgs::addCmdLineOptions( options );
- KApplication::addCmdLineOptions();
+ TDEApplication::addCmdLineOptions();
- KApplication a;
+ TDEApplication a;
TDECmdLineArgs *args = TDECmdLineArgs::parsedArgs();
myTest testObject;
diff --git a/kio/tests/kionetrctest.cpp b/kio/tests/kionetrctest.cpp
index 95b0cf61a..82c669c74 100644
--- a/kio/tests/kionetrctest.cpp
+++ b/kio/tests/kionetrctest.cpp
@@ -48,7 +48,7 @@ int main(int argc, char **argv)
TDECmdLineArgs::addCmdLineOptions( options );
TDECmdLineArgs *args = TDECmdLineArgs::parsedArgs();
int count = args->count();
- KApplication app;
+ TDEApplication app;
if ( !count )
args->usage();
diff --git a/kio/tests/kiopassdlgtest.cpp b/kio/tests/kiopassdlgtest.cpp
index f1dd1a9b0..099ce468b 100644
--- a/kio/tests/kiopassdlgtest.cpp
+++ b/kio/tests/kiopassdlgtest.cpp
@@ -10,7 +10,7 @@ int main ( int argc, char** argv )
{
KAboutData aboutData("kiopassdlgtest", "KIO Password Dialog Test", "1.0");
TDECmdLineArgs::init(argc, argv, &aboutData);
- KApplication app;
+ TDEApplication app;
TQString usr, pass, comment, label;
label = "Site:";
diff --git a/kio/tests/kioslavetest.cpp b/kio/tests/kioslavetest.cpp
index 2e7e398e4..72a7ffb05 100644
--- a/kio/tests/kioslavetest.cpp
+++ b/kio/tests/kioslavetest.cpp
@@ -496,7 +496,7 @@ static KCmdLineOptions options[] =
int main(int argc, char **argv) {
TDECmdLineArgs::init( argc, argv, "kioslavetest", description, version );
TDECmdLineArgs::addCmdLineOptions( options );
- KApplication app;
+ TDEApplication app;
TDECmdLineArgs *args = TDECmdLineArgs::parsedArgs();
diff --git a/kio/tests/kmimefromext.cpp b/kio/tests/kmimefromext.cpp
index bde2ff5ff..026d4173b 100644
--- a/kio/tests/kmimefromext.cpp
+++ b/kio/tests/kmimefromext.cpp
@@ -35,7 +35,7 @@ int main(int argc, char *argv[])
TDECmdLineArgs::addCmdLineOptions( options );
- KApplication app;
+ TDEApplication app;
TDECmdLineArgs *args = TDECmdLineArgs::parsedArgs();
TQString fileName = args->arg( 0 );
diff --git a/kio/tests/kpropsdlgtest.cpp b/kio/tests/kpropsdlgtest.cpp
index 5d01384f6..02a4b6f37 100644
--- a/kio/tests/kpropsdlgtest.cpp
+++ b/kio/tests/kpropsdlgtest.cpp
@@ -17,7 +17,7 @@ int main ( int argc, char** argv )
TDECmdLineArgs::init(argc, argv, &aboutData);
TDECmdLineArgs::addCmdLineOptions( options );
- KApplication app;
+ TDEApplication app;
TDECmdLineArgs *args = TDECmdLineArgs::parsedArgs();
if ( args->count() < 1 )
diff --git a/kio/tests/kprotocolinfotest.cpp b/kio/tests/kprotocolinfotest.cpp
index e8fd7850d..1f4dc95c6 100644
--- a/kio/tests/kprotocolinfotest.cpp
+++ b/kio/tests/kprotocolinfotest.cpp
@@ -30,7 +30,7 @@ int main(int argc, char **argv) {
"1.0");
TDECmdLineArgs::init(argc, argv, &aboutData);
- KApplication app;
+ TDEApplication app;
KURL url;
url.setPath("/tmp");
diff --git a/kio/tests/kruntest.cpp b/kio/tests/kruntest.cpp
index 673948374..d8f47859b 100644
--- a/kio/tests/kruntest.cpp
+++ b/kio/tests/kruntest.cpp
@@ -121,7 +121,7 @@ void checkPDE(const KService &service, const KURL::List &urls, bool hs, bool tf,
int main(int argc, char **argv)
{
- KApplication app( argc, argv, "kruntest", true /* it _has_ a GUI ! */);
+ TDEApplication app( argc, argv, "kruntest", true /* it _has_ a GUI ! */);
// First some non-interactive tests
checkBN( "/usr/bin/ls", true, "ls");
diff --git a/kio/tests/kscantest.cpp b/kio/tests/kscantest.cpp
index 347993af8..14abd1b33 100644
--- a/kio/tests/kscantest.cpp
+++ b/kio/tests/kscantest.cpp
@@ -3,7 +3,7 @@
int main( int argc, char **argv )
{
- KApplication app( argc, argv, "kscantest" );
+ TDEApplication app( argc, argv, "kscantest" );
KScanDialog *dlg = KScanDialog::getScanDialog();
if ( !dlg ) {
tqDebug("*** EEK, no Scan-service available, aborting!");
diff --git a/kio/tests/ksycocatest.cpp b/kio/tests/ksycocatest.cpp
index 086836f37..45f94ac3c 100644
--- a/kio/tests/ksycocatest.cpp
+++ b/kio/tests/ksycocatest.cpp
@@ -67,7 +67,7 @@ void debug(const char *format, const char *txt)
int main(int argc, char *argv[])
{
- KApplication k(argc,argv,"whatever",false/*noGUI*/); // KMessageBox needs KApp for makeStdCaption
+ TDEApplication k(argc,argv,"whatever",false/*noGUI*/); // KMessageBox needs KApp for makeStdCaption
TQCString instname = "kword";
TQString desktopPath = TQString::fromLatin1( "Office/%1.desktop" ).arg( instname );
diff --git a/kio/tests/ksycocaupdatetest.cpp b/kio/tests/ksycocaupdatetest.cpp
index 1d9e3fcaa..e7778e056 100644
--- a/kio/tests/ksycocaupdatetest.cpp
+++ b/kio/tests/ksycocaupdatetest.cpp
@@ -4,7 +4,7 @@
int main(int argc, char *argv[])
{
- KApplication k(argc,argv,"whatever"); // KMessageBox needs KApp for makeStdCaption
+ TDEApplication k(argc,argv,"whatever"); // KMessageBox needs KApp for makeStdCaption
KService::rebuildKSycoca(0);
return 0;
diff --git a/kio/tests/ktradertest.cpp b/kio/tests/ktradertest.cpp
index d2ceb4c00..b05444dfd 100644
--- a/kio/tests/ktradertest.cpp
+++ b/kio/tests/ktradertest.cpp
@@ -37,7 +37,7 @@ int main( int argc, char **argv )
TDECmdLineArgs::addCmdLineOptions( options );
- KApplication app( false, false ); // no GUI
+ TDEApplication app( false, false ); // no GUI
TDECmdLineArgs *args = TDECmdLineArgs::parsedArgs();
diff --git a/kio/tests/kurifiltertest.cpp b/kio/tests/kurifiltertest.cpp
index 6eb661c70..3dbd8c648 100644
--- a/kio/tests/kurifiltertest.cpp
+++ b/kio/tests/kurifiltertest.cpp
@@ -162,7 +162,7 @@ int main(int argc, char **argv)
TDECmdLineArgs::init(argc, argv, &aboutData);
TDECmdLineArgs::addCmdLineOptions( options );
- KApplication app;
+ TDEApplication app;
app.disableAutoDcopRegistration();
// Allow testing of the search engine using both delimiters...
diff --git a/kio/tests/kurlcompletiontest.cpp b/kio/tests/kurlcompletiontest.cpp
index d777fe0df..c8dc99595 100644
--- a/kio/tests/kurlcompletiontest.cpp
+++ b/kio/tests/kurlcompletiontest.cpp
@@ -164,9 +164,9 @@ void KURLCompletionTest::testLocalURL()
int main( int argc, char **argv )
{
- KApplication::disableAutoDcopRegistration();
+ TDEApplication::disableAutoDcopRegistration();
TDECmdLineArgs::init(argc,argv,"kurlcompletiontest", 0, 0, 0, 0);
- KApplication app;
+ TDEApplication app;
{
KURLCompletionTest test;
diff --git a/kio/tests/metatest.cpp b/kio/tests/metatest.cpp
index f450c46c1..034d740ed 100644
--- a/kio/tests/metatest.cpp
+++ b/kio/tests/metatest.cpp
@@ -187,9 +187,9 @@ int main( int argc, char **argv )
TDECmdLineArgs::addCmdLineOptions( options );
// Add options from other components
- KApplication::addCmdLineOptions();
+ TDEApplication::addCmdLineOptions();
- KApplication app;
+ TDEApplication app;
TDECmdLineArgs* args = TDECmdLineArgs::parsedArgs();
diff --git a/kio/tests/netaccesstest.cpp b/kio/tests/netaccesstest.cpp
index 9fb0ff07a..a9aeb66d4 100644
--- a/kio/tests/netaccesstest.cpp
+++ b/kio/tests/netaccesstest.cpp
@@ -24,7 +24,7 @@
int main(int argc, char **argv)
{
- KApplication app( argc, argv, "netaccesstest", true /* it _has_ a GUI ! */);
+ TDEApplication app( argc, argv, "netaccesstest", true /* it _has_ a GUI ! */);
KURL srcURL( "ftp://ftp.kde.org/pub/kde/README" );
KURL tmpURL( "file:/tmp/netaccesstest_README" );
diff --git a/kio/tests/previewtest.cpp b/kio/tests/previewtest.cpp
index f2b740224..52dea6ac7 100644
--- a/kio/tests/previewtest.cpp
+++ b/kio/tests/previewtest.cpp
@@ -55,7 +55,7 @@ void PreviewTest::slotFailed()
int main(int argc, char **argv)
{
- KApplication app(argc, argv, "previewtest");
+ TDEApplication app(argc, argv, "previewtest");
PreviewTest *w = new PreviewTest;
w->show();
app.setMainWidget(w);
diff --git a/kio/tests/speed.cpp b/kio/tests/speed.cpp
index 77cf13764..ae94d83e6 100644
--- a/kio/tests/speed.cpp
+++ b/kio/tests/speed.cpp
@@ -69,7 +69,7 @@ int main(int argc, char **argv) {
TDECmdLineArgs::addCmdLineOptions( options );
- KApplication app;
+ TDEApplication app;
TDECmdLineArgs *args = TDECmdLineArgs::parsedArgs();
diff --git a/kio/kfile/kpropertiesdialog.cpp b/kio/kfile/kpropertiesdialog.cpp
index 6bfe09e8d..a1076c134 100644
--- a/kio/kfile/kpropertiesdialog.cpp
+++ b/kio/kfile/kpropertiesdialog.cpp
@@ -3887,14 +3887,14 @@ void KExecPropsPlugin::slotBrowseExec()
execEdit->setText( path );
}
-class KApplicationPropsPlugin::KApplicationPropsPluginPrivate
+class TDEApplicationPropsPlugin::TDEApplicationPropsPluginPrivate
{
public:
- KApplicationPropsPluginPrivate()
+ TDEApplicationPropsPluginPrivate()
{
m_kdesktopMode = TQCString(tqApp->name()) == "kdesktop"; // nasty heh?
}
- ~KApplicationPropsPluginPrivate()
+ ~TDEApplicationPropsPluginPrivate()
{
}
@@ -3902,10 +3902,10 @@ public:
bool m_kdesktopMode;
};
-KApplicationPropsPlugin::KApplicationPropsPlugin( KPropertiesDialog *_props )
+TDEApplicationPropsPlugin::TDEApplicationPropsPlugin( KPropertiesDialog *_props )
: KPropsDlgPlugin( _props )
{
- d = new KApplicationPropsPluginPrivate;
+ d = new TDEApplicationPropsPluginPrivate;
d->m_frame = properties->addPage(i18n("&Application"));
TQVBoxLayout *toplayout = new TQVBoxLayout( d->m_frame, 0, KDialog::spacingHint());
@@ -4043,23 +4043,23 @@ KApplicationPropsPlugin::KApplicationPropsPlugin( KPropertiesDialog *_props )
this, TQT_SIGNAL( changed() ) );
}
-KApplicationPropsPlugin::~KApplicationPropsPlugin()
+TDEApplicationPropsPlugin::~TDEApplicationPropsPlugin()
{
delete d;
}
// TQString KApplicationPropsPlugin::tabName () const
// {
// return i18n ("&Application");
// }
-void KApplicationPropsPlugin::updateButton()
+void TDEApplicationPropsPlugin::updateButton()
{
addExtensionButton->setEnabled(availableExtensionsList->currentItem()>-1);
delExtensionButton->setEnabled(extensionsList->currentItem()>-1);
}
-void KApplicationPropsPlugin::addMimeType( const TQString & name )
+void TDEApplicationPropsPlugin::addMimeType( const TQString & name )
{
// Add a mimetype to the list of available mime types if not in the extensionsList
@@ -4076,13 +4076,13 @@ void KApplicationPropsPlugin::addMimeType( const TQString & name )
}
}
-bool KApplicationPropsPlugin::supports( KFileItemList _items )
+bool TDEApplicationPropsPlugin::supports( KFileItemList _items )
{
// same constraints as KExecPropsPlugin : desktop file with Type = Application
return KExecPropsPlugin::supports( _items );
}
-void KApplicationPropsPlugin::applyChanges()
+void TDEApplicationPropsPlugin::applyChanges()
{
TQString path = properties->kurl().path();
@@ -4121,7 +4121,7 @@ void KApplicationPropsPlugin::applyChanges()
config.sync();
}
-void KApplicationPropsPlugin::slotAddExtension()
+void TDEApplicationPropsPlugin::slotAddExtension()
{
TQListBoxItem *item = availableExtensionsList->firstItem();
TQListBoxItem *nextItem;
@@ -4143,7 +4143,7 @@ void KApplicationPropsPlugin::slotAddExtension()
updateButton();
}
-void KApplicationPropsPlugin::slotDelExtension()
+void TDEApplicationPropsPlugin::slotDelExtension()
{
TQListBoxItem *item = extensionsList->firstItem();
TQListBoxItem *nextItem;
@@ -4043,23 +4043,23 @@ KApplicationPropsPlugin::KApplicationPropsPlugin( KPropertiesDialog *_props )
delete d;
}
-// TQString KApplicationPropsPlugin::tabName () const
+// TQString TDEApplicationPropsPlugin::tabName () const
// {
// return i18n ("&Application");